Creating OpenOffice.org POT files — Translate Toolkit 2.5.0 documentation

# Creating OpenOffice.org POT files

This quick start guide shows you how to create the PO Template files for your OpenOffice.org translation.

## Quick Start

1. Download the latest POT and GSI files
2. `oo2po -P <gsi> <new-pots>`

## Detailed Description

### Download the latest POT and GSI files

The POT files produced by Pavel Janik contain the associated en-US.sdf file that you need to create your own languages SDF file. This is the same file that produces the POT files. So to begin translating you don’t need to go further than this.

- Download the latest POT and GSI files

However, you will need this file if you need to use some of the other features of oo2po such as changing the source language from English.

### Produce the POT files using oo2po

    oo2po -P <gsi> <new-pots>
    oo2po -P en-US.gsi pot

This takes the en-US.gsi file and creates POT files in the pot directory. The `-P` option ensures that .pot files are created instead of .po file.

If you want to create one large .pot file instead of a lot of small ones, you should use the:

    oo2po -P --multifile=onefile en-US.gsi pot

option as described in oo2po.

### Produce a POT files with French source text

You will need to have access to a French GSI file. The following commands will create a set of POT files with French as the source language:

    oo2po -P --source-language=fr fr.gsi pot-fr

This will take translations from fr.gsi and create a set of POT files in pot-fr. These POT files will have French as the source language. You need to make sure that fr.gsi is in fact up to date.